pub struct IfExpr {
pub keyword: If,
pub condition: Expr,
pub then_branch: Block,
pub else_ifs: Vec<ElseIf>,
pub else_branch: Option<Else>,
}Expand description
If construction: Condition is any valid rust syntax, while body is expected yo be *ml element.
Example:
@if x > 2 { <div></div> }
@if let Some(x) = foo { <div></div> }
As in rust can contain arbitrary amount of else if .. {..} constructs and
one else {..}.
Fields
keyword: Ifcondition: Exprthen_branch: Blockelse_ifs: Vec<ElseIf>else_branch: Option<Else>Implementations
Sourceimpl IfExpr
impl IfExpr
pub fn visit_custom_children<V: Visitor<EscapeCode>>( visitor: &mut V, expr: &mut Self, ) -> bool